==> styled-bootstrap-0.1.7-0.tgz: package/lib/Dropdown/stories/Dropdown.story.js <==
var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _templateObject = _taggedTemplateLiteral(['\n  &:after {\n    display: inline-block;\n    width: 0;\n    height: 0;\n    margin-left: ', ';\n    vertical-align: middle;\n    content: \'\';\n    border-top: ', ' solid;\n    border-right: ', ' solid transparent;\n    border-left: ', ' solid transparent;\n  }\n\n  &:empty:after {\n    margin-left: 0;\n  }\n'], ['\n  &:after {\n    display: inline-block;\n    width: 0;\n    height: 0;\n    margin-left: ', ';\n    vertical-align: middle;\n    content: \'\';\n    border-top: ', ' solid;\n    border-right: ', ' solid transparent;\n    border-left: ', ' solid transparent;\n  }\n\n  &:empty:after {\n    margin-left: 0;\n  }\n']);

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import React, { Component } from 'react';

import { storiesOf } from '@storybook/react';
import { host } from 'storybook-host';

import { caretWidth } from '../../utils/src/defaultTheme';

import Dropdown from '../Dropdown';
import Button from '../../Button';

var ButtonWithCaret = Button.extend(_templateObject, caretWidth, caretWidth, caretWidth, caretWidth);

var DropdownWrapper = function (_Component) {
  _inherits(DropdownWrapper, _Component);

  function DropdownWrapper(props, context) {
    _classCallCheck(this, DropdownWrapper);

    var _this = _possibleConstructorReturn(this, (DropdownWrapper.__proto__ || Object.getPrototypeOf(DropdownWrapper)).call(this, props, context));

    _this.toggleDropdown = function () {
      _this.setState(function (_ref) {
        var isOpen = _ref.isOpen;
        return {
          isOpen: !isOpen
        };
      });
    };

    _this.state = {
      isOpen: true
    };
    return _this;
  }

  _createClass(DropdownWrapper, [{
    key: 'render',
    value: function render() {
      return React.createElement(
        Dropdown,
        { isOpen: this.state.isOpen, align: this.props.align },
        React.createElement(
          ButtonWithCaret,
          { color: 'secondary', onClick: this.toggleDropdown },
          'Dropdown button'
        ),
        React.createElement(
          Dropdown.Menu,
          null,
          React.createElement(
            Dropdown.Item,
            { href: '#' },
            'Action'
          ),
          React.createElement(
            Dropdown.Item,
            { href: '#', active: true },
            'Active item'
          ),
          React.createElement(
            Dropdown.Item,
            { href: '#' },
            'Another action'
          ),
          React.createElement(
            Dropdown.Item,
            { href: '#', disabled: true },
            'disabled item'
          ),
          React.createElement(
            Dropdown.Item,
            { href: '#' },
            'Something else here'
          )
        )
      );
    }
  }]);

  return DropdownWrapper;
}(Component);

var DropdownWithDivider = function (_Component2) {
  _inherits(DropdownWithDivider, _Component2);

  function DropdownWithDivider(props, context) {
    _classCallCheck(this, DropdownWithDivider);

    var _this2 = _possibleConstructorReturn(this, (DropdownWithDivider.__proto__ || Object.getPrototypeOf(DropdownWithDivider)).call(this, props, context));

    _this2.toggleDropdown = function () {
      _this2.setState(function (_ref2) {
        var isOpen = _ref2.isOpen;
        return {
          isOpen: !isOpen
        };
      });
    };

    _this2.state = {
      isOpen: true
    };
    return _this2;
  }

  _createClass(DropdownWithDivider, [{
    key: 'render',
    value: function render() {
      return React.createElement(
        Dropdown,
        { isOpen: this.state.isOpen },
        React.createElement(
          ButtonWithCaret,
          { color: 'secondary', onClick: this.toggleDropdown },
          'Dropdown button'
        ),
        React.createElement(
          Dropdown.Menu,
          null,
          React.createElement(
            Dropdown.Item,
            { href: '#' },
            'Action'
          ),
          React.createElement(
            Dropdown.Item,
            { href: '#' },
            'Another action'
          ),
          React.createElement(
            Dropdown.Item,
            { href: '#', disabled: true },
            'disabled item'
          ),
          React.createElement(
            Dropdown.Item,
            { href: '#' },
            'Something else here'
          ),
          React.createElement(Dropdown.Divider, null),
          React.createElement(
            Dropdown.Item,
            { href: '#' },
            'Active item'
          )
        )
      );
    }
  }]);

  return DropdownWithDivider;
}(Component);

var DropdownWithHeader = function (_Component3) {
  _inherits(DropdownWithHeader, _Component3);

  function DropdownWithHeader(props, context) {
    _classCallCheck(this, DropdownWithHeader);

    var _this3 = _possibleConstructorReturn(this, (DropdownWithHeader.__proto__ || Object.getPrototypeOf(DropdownWithHeader)).call(this, props, context));

    _this3.toggleDropdown = function () {
      _this3.setState(function (_ref3) {
        var isOpen = _ref3.isOpen;
        return {
          isOpen: !isOpen
        };
      });
    };

    _this3.state = {
      isOpen: true
    };
    return _this3;
  }

  _createClass(DropdownWithHeader, [{
    key: 'render',
    value: function render() {
      return React.createElement(
        Dropdown,
        { isOpen: this.state.isOpen },
        React.createElement(
          ButtonWithCaret,
          { color: 'secondary', onClick: this.toggleDropdown },
          'Dropdown button'
        ),
        React.createElement(
          Dropdown.Menu,
          null,
          React.createElement(
            Dropdown.Header,
            { as: 'h3' },
            'Dropdown header'
          ),
          React.createElement(
            Dropdown.Item,
            { href: '#' },
            'Another action'
          ),
          React.createElement(
            Dropdown.Item,
            { href: '#' },
            'Something else here'
          ),
          React.createElement(
            Dropdown.Item,
            { href: '#' },
            'Something here'
          )
        )
      );
    }
  }]);

  return DropdownWithHeader;
}(Component);

export default storiesOf('Dropdown', module).addDecorator(host({
  align: 'center'
})).add('Dropdown', function () {
  return React.createElement(DropdownWrapper, null);
}).add('Dropdown right aligned', function () {
  return React.createElement(DropdownWrapper, { align: 'right' });
}).add('Dropdown with Divider', function () {
  return React.createElement(DropdownWithDivider, null);
}).add('Dropdown with Header', function () {
  return React.createElement(DropdownWithHeader, null);
});

==> styled-bootstrap-0.1.9.tgz: package/lib/Dropdown/stories/Dropdown.story.js <==
var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _templateObject = _taggedTemplateLiteral(['\n  &:after {\n    display: inline-block;\n    width: 0;\n    height: 0;\n    margin-left: ', ';\n    vertical-align: middle;\n    content: \'\';\n    border-top: ', ' solid;\n    border-right: ', ' solid transparent;\n    border-left: ', ' solid transparent;\n  }\n\n  &:empty:after {\n    margin-left: 0;\n  }\n'], ['\n  &:after {\n    display: inline-block;\n    width: 0;\n    height: 0;\n    margin-left: ', ';\n    vertical-align: middle;\n    content: \'\';\n    border-top: ', ' solid;\n    border-right: ', ' solid transparent;\n    border-left: ', ' solid transparent;\n  }\n\n  &:empty:after {\n    margin-left: 0;\n  }\n']);

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import React, { Component } from 'react';

import { storiesOf } from '@storybook/react';
import { host } from 'storybook-host';
import { withKnobs, boolean, select } from '@storybook/addon-knobs/react';

import { caretWidth } from '../../utils/defaultTheme';

import Dropdown from '../Dropdown';
import Button from '../../Button';

var ButtonWithCaret = Button.extend(_templateObject, caretWidth, caretWidth, caretWidth, caretWidth);

var DropdownWrapper = function (_Component) {
  _inherits(DropdownWrapper, _Component);

  function DropdownWrapper(props, context) {
    _classCallCheck(this, DropdownWrapper);

    var _this = _possibleConstructorReturn(this, (DropdownWrapper.__proto__ || Object.getPrototypeOf(DropdownWrapper)).call(this, props, context));

    _this.toggleDropdown = function () {
      _this.setState({
        isOpen: !_this.state.isOpen
      });
    };

    _this.state = {
      isOpen: false
    };
    return _this;
  }

  _createClass(DropdownWrapper, [{
    key: 'render',
    value: function render() {
      return React.createElement(
        Dropdown,
        {
          isOpen: boolean('isOpen', this.state.isOpen),
          align: this.props.align
        },
        React.createElement(
          ButtonWithCaret,
          { onClick: this.toggleDropdown },
          'Dropdown button'
        ),
        React.createElement(
          Dropdown.Menu,
          null,
          React.createElement(
            Dropdown.Item,
            { href: '#' },
            'Action'
          ),
          React.createElement(
            Dropdown.Item,
            { href: '#', active: true },
            'Active item'
          ),
          React.createElement(
            Dropdown.Item,
            { href: '#' },
            'Another action'
          ),
          React.createElement(
            Dropdown.Item,
            { href: '#', disabled: true },
            'disabled item'
          ),
          React.createElement(
            Dropdown.Item,
            { href: '#' },
            'Something else here'
          )
        )
      );
    }
  }]);

  return DropdownWrapper;
}(Component);

var DropdownWithDivider = function (_Component2) {
  _inherits(DropdownWithDivider, _Component2);

  function DropdownWithDivider(props, context) {
    _classCallCheck(this, DropdownWithDivider);

    var _this2 = _possibleConstructorReturn(this, (DropdownWithDivider.__proto__ || Object.getPrototypeOf(DropdownWithDivider)).call(this, props, context));

    _this2.toggleDropdown = function () {
      _this2.setState(function (_ref) {
        var isOpen = _ref.isOpen;
        return {
          isOpen: !isOpen
        };
      });
    };

    _this2.state = {
      isOpen: true
    };
    return _this2;
  }

  _createClass(DropdownWithDivider, [{
    key: 'render',
    value: function render() {
      return React.createElement(
        Dropdown,
        { isOpen: this.state.isOpen },
        React.createElement(
          ButtonWithCaret,
          {
            color: 'success',
            size: 'large',
            onClick: this.toggleDropdown
          },
          'Dropdown button'
        ),
        React.createElement(
          Dropdown.Menu,
          null,
          React.createElement(
            Dropdown.Item,
            { href: '#' },
            'Action'
          ),
          React.createElement(
            Dropdown.Item,
            { href: '#' },
            'Another action'
          ),
          React.createElement(
            Dropdown.Item,
            { href: '#', disabled: true },
            'disabled item'
          ),
          React.createElement(
            Dropdown.Item,
            { href: '#' },
            'Something else here'
          ),
          React.createElement(Dropdown.Divider, null),
          React.createElement(
            Dropdown.Item,
            { href: '#' },
            'Active item'
          )
        )
      );
    }
  }]);

  return DropdownWithDivider;
}(Component);

var DropdownWithHeader = function (_Component3) {
  _inherits(DropdownWithHeader, _Component3);

  function DropdownWithHeader(props, context) {
    _classCallCheck(this, DropdownWithHeader);

    var _this3 = _possibleConstructorReturn(this, (DropdownWithHeader.__proto__ || Object.getPrototypeOf(DropdownWithHeader)).call(this, props, context));

    _this3.toggleDropdown = function () {
      _this3.setState(function (_ref2) {
        var isOpen = _ref2.isOpen;
        return {
          isOpen: !isOpen
        };
      });
    };

    _this3.state = {
      isOpen: true
    };
    return _this3;
  }

  _createClass(DropdownWithHeader, [{
    key: 'render',
    value: function render() {
      return React.createElement(
        Dropdown,
        { isOpen: this.state.isOpen },
        React.createElement(
          ButtonWithCaret,
          { color: 'warning', onClick: this.toggleDropdown },
          'Dropdown button'
        ),
        React.createElement(
          Dropdown.Menu,
          null,
          React.createElement(
            Dropdown.Header,
            { as: 'h3' },
            'Dropdown header'
          ),
          React.createElement(
            Dropdown.Item,
            { href: '#' },
            'Another action'
          ),
          React.createElement(
            Dropdown.Item,
            { href: '#' },
            'Something else here'
          ),
          React.createElement(
            Dropdown.Item,
            { href: '#' },
            'Something here'
          )
        )
      );
    }
  }]);

  return DropdownWithHeader;
}(Component);

export default storiesOf('Dropdown', module).addDecorator(withKnobs).addDecorator(host({
  align: 'center'
})).add('Dropdown', function () {
  return React.createElement(DropdownWrapper, {
    align: select('Align', {
      left: 'Left',
      right: 'Right'
    }, 'left')
  });
}).add('Dropdown right aligned', function () {
  return React.createElement(DropdownWrapper, {
    align: select('Align', {
      left: 'Left',
      right: 'Right'
    }, 'right')
  });
}).add('Dropdown with Divider', function () {
  return React.createElement(DropdownWithDivider, null);
}).add('Dropdown with Header', function () {
  return React.createElement(DropdownWithHeader, null);
});
